@@ -174,7 +174,7 @@ void processArgs(int argc, char **argv)
     } else if (strcmp(argv[i],"-resurface") == 0) {
       resurface=True;
     } else if (strcmp(argv[i],"-noreconnect") == 0) {
-      resurface=False;
+      reconnect=False;
     } else if (strcmp(argv[i],"-shared") == 0) {
       shareDesktop = True;
     } else if (strcmp(argv[i],"-edgewidth") == 0) {
