@@ -495,6 +495,8 @@ Bool CreateXWindow(void)
      pointer_speed *= num;
      pointer_speed /= den;
      pointer_warp_threshold = thr * thr;
+     if(debug)
+       fprintf(stderr,"USING DGA\n");
    }
  }
 #endif
@@ -1041,7 +1043,7 @@ static Bool HandleTopLevelEvent(XEvent *ev)
 
 	do
 	{
-#ifdef SERVER_HAS_XF86DGA
+#ifdef HAVE_XF86DGA
 	  if(server_has_xf86dga)
 	  {
 	    offset.x+=ev->xmotion.x_root;
@@ -1062,8 +1064,8 @@ static Bool HandleTopLevelEvent(XEvent *ev)
 	    motion_events++;
 	    
 	    if(next_origo &&
-	       coord_dist_sq(new_location, *next_origo) < coord_dist_sq(new_location, current_location) ||
-	       coord_dist_from_edge(new_location) < motion_events)
+	       (coord_dist_sq(new_location, *next_origo) < coord_dist_sq(new_location, current_location) ||
+                coord_dist_from_edge(new_location) < motion_events))
 	    {
 	      current_origo=next_origo;
 	      current_location=*next_origo;
