@@ -85,6 +85,8 @@ int main(int argc, char **argv)
 	    
 	  default:
 	    while(waitpid(pid, &status, 0) < 0 && errno==EINTR);
+            if(debug)
+              fprintf(stderr,"Child exited with status %d\n",status);
 	    continue;
 	}
 	break;
