@@ -79,10 +79,12 @@ extern Bool debug;
 extern Bool trimsel;
 extern Bool resurface;
 extern Bool reconnect;
+extern int temp_file_fd;
 
 extern int noblank;
 extern int no_wakeup_delay;
 extern int last_event_time;
+extern float acceleration;
 
 extern void processArgs(int argc, char **argv);
 extern void usage();
@@ -126,7 +128,6 @@ extern Display *dpy;
 extern unsigned long BGR233ToPixel[];
 
 extern Bool CreateXWindow();
-extern void ShutdownX();
 extern Bool HandleXEvents();
 extern Bool AllXEventsPredicate(Display *dpy, XEvent *ev, char *arg);
 
@@ -138,10 +139,13 @@ extern Bool errorMessageFromReadExact;
 extern Bool ReadExact(int sock, char *buf, int n);
 extern Bool WriteExact(int sock, char *buf, int n);
 extern int ListenAtTcpPort(int port);
+extern int getFreePort();
 extern int ConnectToTcpAddr(unsigned int host, int port);
 extern int AcceptTcpConnection(int listenSock);
 extern int StringToIPAddr(const char *str, unsigned int *addr);
 extern Bool SameMachine(int sock);
+extern Bool useSSHTunnel;
+extern char *useSSHGateway;
 
 
 /* listen.c */
